diff -ur deborphan-1.7.28/doc/deborphan.1 deborphan/doc/deborphan.1
--- deborphan-1.7.28/doc/deborphan.1	2009-02-19 12:49:21.000000000 +0100
+++ deborphan/doc/deborphan.1	2010-04-25 18:03:09.940920383 +0200
@@ -220,9 +220,10 @@
 
 .TP
 \fBsection\fP
-This option tries to find libraries that were accidentally placed in the 
-wrong section. It tries to match \fI^lib\fR, but not if it ends
-in one of: \fI\-dbg\fR, \fI\-doc\fR, \fI\-perl\fR, or \fI\-dev\fR.
+This option tries to find libraries that were accidentally placed in the
+wrong section. It tries to match \fI^lib\fR, but not if it ends in one of:
+\fI\-bin\fR, \fI\-tools\fR, \fI\-utils\fR, \fI\-dev\fR, \fI\-dbg\fR,
+\fI\-doc or \fI\-perl\fR.
 
 .TP
 \fBall\fP
diff -ur deborphan-1.7.28/src/pkginfo.c deborphan/src/pkginfo.c
--- deborphan-1.7.28/src/pkginfo.c	2009-02-19 12:49:22.000000000 +0100
+++ deborphan/src/pkginfo.c	2010-04-25 18:03:12.935027789 +0200
@@ -74,7 +74,7 @@
 	if (guess_chk(GUESS_KERNEL))
 	    strcat(guess, "(-modules|^nvidia-kernel)-.*[[:digit:]]+\\.[[:digit:]]+\\.[[:digit:]]+");
 	if (guess_chk(GUESS_SECTION)) {
-	    regcomp(&re_gnugrepv, "(-perl|-dev|-doc|-dbg)$", 
+	    regcomp(&re_gnugrepv, "-(bin|tools|utils|dev|dbg|doc|perl)$", 
 		    REG_EXTENDED | REG_FLAGS);
 	}
 
@@ -365,8 +365,9 @@
     if (!guess_chk(GUESS_SECTION))
         return 0;
 
     /* Check whether the package begins with lib, but not if it ends in one of:
      * -dbg, -doc, -perl or -dev. This is what --guess-section does.
      */
     if (!strncmp(package->self.name, "lib", 3))
 	if (regexec(&re_gnugrepv, package->self.name, 0, NULL, 0))
@@ -365,8 +365,9 @@
         return 0;
 
-    /* Check whether the package begins with lib, but not if it ends in one of:
-     * -dbg, -doc, -perl or -dev. This is what --guess-section does.
+    /* Check whether the package begins with lib, but not if it ends in one
+     * of: -bin, -tools, -utils, -dev, -dbg, -doc or -perl. This is what
+     * --guess-section does.
      */
     if (!strncmp(package->self.name, "lib", 3))
